summaryrefslogtreecommitdiff
path: root/epan/addr_resolv.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/addr_resolv.h')
-rw-r--r--epan/addr_resolv.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/addr_resolv.h b/epan/addr_resolv.h
index cd2979bc46..ecd94c61a2 100644
--- a/epan/addr_resolv.h
+++ b/epan/addr_resolv.h
@@ -132,7 +132,7 @@ extern gchar *get_dccp_port(guint port);
*/
WS_DLL_PUBLIC gchar *get_sctp_port(guint port);
/* get_addr_name takes as input an "address", as defined in address.h */
/* it returns a string that contains: */
/* - if the address is of a type that can be translated into a name, and the user */
/* has activated name resolution, the translated name */
@@ -142,16 +142,16 @@ WS_DLL_PUBLIC gchar *get_sctp_port(guint port);
/* address 10.10.10.10 */
WS_DLL_PUBLIC
-const gchar *get_addr_name(const address *addr);
-const gchar *se_get_addr_name(const address *addr);
+const gchar *ep_address_to_display(const address *addr);
-/* get_addr_name_buf solves an address in the same way as get_addr_name above */
+/* get_addr_name_buf solves an address in the same way as ep_address_to_display above */
/* The difference is that get_addr_name_buf takes as input a buffer, into which it puts */
/* the result which is always NUL ('\0') terminated. The buffer should be large enough to */
/* contain size characters including the terminator */
void get_addr_name_buf(const address *addr, gchar *buf, gsize size);
+const gchar *get_addr_name(const address *addr);
/*
* Asynchronous host name lookup initialization, processing, and cleanup
@@ -132,7 +132,7 @@ extern gchar *get_dccp_port(guint port);
*/
WS_DLL_PUBLIC gchar *get_sctp_port(guint port);
-/* get_addr_name takes as input an "address", as defined in address.h */
+/* ep_address_to_display takes as input an "address", as defined in address.h */
/* it returns a string that contains: */
/* - if the address is of a type that can be translated into a name, and the user */